﻿'GUI for Microsoft(R) SharePoint Workflow Package Generator
'A simple GUI for the above mentioned command line tool from Microsoft,
'which is shipped as part of the VSTO Power Tools

'Written by Alessandro Del Sole - alessandro.delsole@visual-basic.it

'CodePlex project URL: www.codeplex.com/wpkgengui

'This source code is provided "AS IS" with no warranties and is released under the
'Microsoft Public License
'The author is not responsible for the usage, bad usage or damages deriving from the usage
'of this source code.

Imports Microsoft.Win32

Class Window1

    Private toolPath As String = My.Computer.FileSystem.SpecialDirectories.ProgramFiles + "\Microsoft VSTO Power Tools 1.0\workflow package generator\workflowpackagegen.exe"

    Private Sub QuitButton_Click(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs) Handles QuitButton.Click
        Application.Current.Shutdown()
    End Sub

    Private Sub BrowseButton_Click(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs) Handles BrowseButton.Click

        'Select a Manifest
        Dim ofd As New OpenFileDialog

        With ofd
            .Title = "Select an XML Manifest"
            .Filter = "XML files|*.Xml|All files|*.*"

            Dim result As Nullable(Of Boolean) = .ShowDialog

            If result = True Then
                fileNameTextBox.Text = .FileName
            End If
        End With
    End Sub

    Private Sub GenerateButton_Click(ByVal sender As System.Object, ByVal e As System.Windows.RoutedEventArgs) Handles GenerateButton.Click

        If String.IsNullOrEmpty(fileNameTextBox.Text) = True Then
            MessageBox.Show("No Manifest has been selected yet. Please choose one first, then retry", "", MessageBoxButton.OK, MessageBoxImage.Warning)
            Exit Sub
        Else

            Try

                Dim fbd As New Windows.Forms.FolderBrowserDialog
                Dim outputPath As String = Nothing

                With fbd
                    .Description = "Select package's output dir"

                    If .ShowDialog() = Forms.DialogResult.OK And String.IsNullOrEmpty(.SelectedPath) = False Then
                        outputPath = .SelectedPath

                        'Start the command line tool, by passing some switches as arguments
                        Dim pi As New ProcessStartInfo
                        With pi
                            .Arguments = "/featureManifest:" + fileNameTextBox.Text + " /OutputPath:" + outputPath
                            .FileName = toolPath
                            .CreateNoWindow = True
                            .UseShellExecute = False
                            .RedirectStandardOutput = True
                        End With

                        Dim p As New Process
                        p.StartInfo = pi
                        p.Start()
                        'Output redirection
                        outputTextBox.Text = p.StandardOutput.ReadToEnd
                        p.WaitForExit()

                    End If


                End With

            Catch ex As Exception
                MessageBox.Show(ex.ToString, "", MessageBoxButton.OK, MessageBoxImage.Error)
            End Try
        End If
    End Sub

    Private Sub Window1_Loaded(ByVal sender As Object, ByVal e As System.Windows.RoutedEventArgs) Handles Me.Loaded
        If IO.File.Exists(toolPath) = False Then
            MessageBox.Show("Visual Studio Tool for Office Power Tools not found. Please install and retry.", "", MessageBoxButton.OK, MessageBoxImage.Error)
            Application.Current.Shutdown()
        End If
    End Sub


    Private Sub MsBuildGen(ByVal sender As Object, ByVal e As RoutedEventArgs)

        'Shows the MSBuild generated task for the selected manifest
        If String.IsNullOrEmpty(fileNameTextBox.Text) = True Then
            MessageBox.Show("No Manifest has been selected yet. Please choose one first, then retry", "", MessageBoxButton.OK, MessageBoxImage.Warning)
            Exit Sub

        Else

            Dim s As String = "<Target Name=""AfterBuild"">" + Environment.NewLine _
                             + "    <Exec Command=""&quot;" + toolPath + Environment.NewLine + "&quot; /featureManifest:" + fileNameTextBox.Text + """ ContinueOnError=""true"">" + Environment.NewLine _
                             + "     </Exec>" + Environment.NewLine + "</Target>"

            outputTextBox.Text = s
        End If

    End Sub
End Class
